CsvInput class

Read from CSV

Inheritance

Constructors

CsvInput(Map config, {ProgressBloc? progress})
Create a new instance.

Properties

cache → PackedDataCache?
Cache
finalinherited
config → Map
Provided configuration, usually passed from the DatasetDescriptor
finalinherited
conversationBatch → int
Conversation batch size
final
description → String
A description of the transformer.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
path → String
Input file path
final
progress → ProgressBloc?
Progress
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepDescription → String
A user supplied description of the transformation step as it relates to the data being processed.
finalinherited

Methods

bind(Stream<List<Conversation>> incoming) → Stream<List<Conversation>>
Transforms the provided stream.
override
cast<RS, RT>() → StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited